<?php
/*
 * Copyright 2011 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Generates a Line Chart for a report.
 *
 * @author Silvano Luciani <silvano.luciani@gmail.com>
 */
class GenerateLineChart extends BaseExample {
  public function render($current_userID = '') {
    $startDate = $this->getSixMonthsBeforeNow();
    $endDate = $this->getNow();
    $account_id = get_option('WordCents_account_id'.$current_userID);
    $metricAr = get_option('WordCents_Metrics'.$current_userID);
	if (!(isset($metricAr) && is_array($metricAr)))
		$metricAr = array('AD_REQUESTS','INDIVIDUAL_AD_IMPRESSIONS');
    $columns = array(array('string', 'Day'));
    foreach ($metricAr as $metric)
    	$columns[] = array('number',str_replace('_',' ',$metric));
    $optParams = array(
        'metric' => $metricAr,
        'dimension' => array('DATE'),
        'filter' => 'AD_'.(count(explode(':', $account_id.':')) > 2?'UNIT':'CLIENT').'_ID=='.get_option('WordCents_account_id'.$current_userID),
       	'sort' => 'DATE');
    $report = $this->adSenseService->reports->generate($startDate, $endDate, $optParams);
    foreach ($report['rows'] as &$row)
	    for ($r=1;$r<count($row);$r++)
    		$row[$r] = (float)$row[$r];
    $data1 = json_encode($report['rows']);
    $type = 'LineChart';
    print generateChartHtml($data1, $columns, $type, json_encode(array('title' => "adSense Data for $startDate through $endDate")), 'dataChart1');
   }
}

